@@ -20,6 +20,7 @@
 package org.apache.skywalking.mqe.rt.type;
 
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.List;
 import lombok.Data;
 import org.apache.skywalking.oap.server.core.query.type.KeyValue;
@@ -27,4 +28,8 @@ import org.apache.skywalking.oap.server.core.query.type.KeyValue;
 @Data
 public class Metadata {
     private List<KeyValue> labels  = new ArrayList<>();
+
+    public void sortLabelsByKey(Comparator<String> comparator) {
+        labels.sort(Comparator.comparing(KeyValue::getKey, comparator));
+    }
 }
