@@ -18,6 +18,7 @@
 
 package org.apache.skywalking.oap.server.core.analysis.meter.function.sumpermin;
 
+import java.util.Objects;
 import lombok.Getter;
 import lombok.Setter;
 import org.apache.skywalking.oap.server.core.UnexpectedException;
@@ -29,8 +30,6 @@ import org.apache.skywalking.oap.server.core.analysis.meter.function.MeterFuncti
 import org.apache.skywalking.oap.server.core.analysis.metrics.DataTable;
 import org.apache.skywalking.oap.server.core.analysis.metrics.LabeledValueHolder;
 import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
-import org.apache.skywalking.oap.server.core.analysis.metrics.annotation.Entrance;
-import org.apache.skywalking.oap.server.core.analysis.metrics.annotation.SourceFrom;
 import org.apache.skywalking.oap.server.core.remote.grpc.proto.RemoteData;
 import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
@@ -39,8 +38,6 @@ import org.apache.skywalking.oap.server.core.storage.type.Convert2Entity;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Storage;
 import org.apache.skywalking.oap.server.core.storage.type.StorageBuilder;
 
-import java.util.Objects;
-
 @MeterFunction(functionName = "sumPerMinLabeled")
 public abstract class SumPerMinLabeledFunction extends Meter implements AcceptableValue<DataTable>, LabeledValueHolder {
 
@@ -70,11 +67,6 @@ public abstract class SumPerMinLabeledFunction extends Meter implements Acceptab
     @BanyanDB.MeasureField
     private DataTable total = new DataTable(30);
 
-    @Entrance
-    public final void combine(@SourceFrom DataTable value) {
-        this.total.append(value);
-    }
-
     @Override
     public void accept(MeterEntity entity, DataTable value) {
         setEntityId(entity.id());
@@ -90,7 +82,7 @@ public abstract class SumPerMinLabeledFunction extends Meter implements Acceptab
     @Override
     public boolean combine(Metrics metrics) {
         final SumPerMinLabeledFunction sumPerMinLabeledFunction = (SumPerMinLabeledFunction) metrics;
-        combine(sumPerMinLabeledFunction.getTotal());
+        this.total.append(sumPerMinLabeledFunction.getTotal());
         return true;
     }
 
