@@ -29,6 +29,9 @@ import com.linecorp.armeria.server.annotation.Get;
 import com.linecorp.armeria.server.annotation.Param;
 import com.linecorp.armeria.server.annotation.Path;
 import com.linecorp.armeria.server.annotation.Post;
+import java.util.LinkedHashSet;
+import java.util.Set;
+import java.util.stream.Collectors;
 import org.antlr.v4.runtime.misc.ParseCancellationException;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -40,8 +43,7 @@ import org.antlr.v4.runtime.CharStreams;
 import org.antlr.v4.runtime.CommonTokenStream;
 import org.antlr.v4.runtime.tree.ParseTree;
 import org.apache.skywalking.oap.query.graphql.resolver.MetadataQueryV2;
-import org.apache.skywalking.oap.query.graphql.resolver.MetricsQuery;
-import org.apache.skywalking.oap.query.graphql.resolver.RecordsQuery;
+import org.apache.skywalking.oap.query.promql.PromQLConfig;
 import org.apache.skywalking.oap.query.promql.entity.ErrorType;
 import org.apache.skywalking.oap.query.promql.entity.LabelName;
 import org.apache.skywalking.oap.query.promql.entity.LabelValuePair;
@@ -49,6 +51,7 @@ import org.apache.skywalking.oap.query.promql.entity.MetricInstantData;
 import org.apache.skywalking.oap.query.promql.entity.MetricMetadata;
 import org.apache.skywalking.oap.query.promql.entity.MetricRangeData;
 import org.apache.skywalking.oap.query.promql.entity.TimeValuePair;
+import org.apache.skywalking.oap.query.promql.entity.response.BuildInfoRsp;
 import org.apache.skywalking.oap.query.promql.entity.response.ExprQueryRsp;
 import org.apache.skywalking.oap.query.promql.entity.MetricInfo;
 import org.apache.skywalking.oap.query.promql.entity.response.LabelValuesQueryRsp;
@@ -69,16 +72,25 @@ import org.apache.skywalking.oap.query.promql.rt.result.MetricsRangeResult;
 import org.apache.skywalking.oap.query.promql.rt.PromQLExprQueryVisitor;
 import org.apache.skywalking.oap.query.promql.rt.result.ParseResult;
 import org.apache.skywalking.oap.query.promql.rt.result.ScalarResult;
+import org.apache.skywalking.oap.server.core.CoreModule;
 import org.apache.skywalking.oap.server.core.analysis.IDManager;
 import org.apache.skywalking.oap.server.core.analysis.Layer;
 import org.apache.skywalking.oap.server.core.analysis.manual.endpoint.EndpointTraffic;
 import org.apache.skywalking.oap.server.core.analysis.manual.instance.InstanceTraffic;
 import org.apache.skywalking.oap.server.core.analysis.manual.service.ServiceTraffic;
+import org.apache.skywalking.oap.server.core.analysis.metrics.DataLabel;
+import org.apache.skywalking.oap.server.core.query.AggregationQueryService;
 import org.apache.skywalking.oap.server.core.query.DurationUtils;
 import org.apache.skywalking.oap.server.core.query.MetricDefinition;
+import org.apache.skywalking.oap.server.core.query.MetricsMetadataQueryService;
+import org.apache.skywalking.oap.server.core.query.MetricsQueryService;
+import org.apache.skywalking.oap.server.core.query.RecordQueryService;
 import org.apache.skywalking.oap.server.core.query.enumeration.Scope;
+import org.apache.skywalking.oap.server.core.query.enumeration.Step;
 import org.apache.skywalking.oap.server.core.query.input.Duration;
 import org.apache.skywalking.oap.server.core.query.type.Endpoint;
+import org.apache.skywalking.oap.server.core.query.type.KeyValue;
+import org.apache.skywalking.oap.server.core.query.type.MetricsValues;
 import org.apache.skywalking.oap.server.core.query.type.Service;
 import org.apache.skywalking.oap.server.core.query.type.ServiceInstance;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
@@ -87,19 +99,61 @@ import org.apache.skywalking.oap.server.library.module.ModuleManager;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
 import org.apache.skywalking.promql.rt.grammar.PromQLLexer;
 import org.apache.skywalking.promql.rt.grammar.PromQLParser;
+import org.joda.time.DateTime;
+import org.joda.time.format.ISODateTimeFormat;
 
 import static org.apache.skywalking.oap.query.promql.rt.PromOpUtils.formatDoubleValue;
 
 public class PromQLApiHandler {
     private final MetadataQueryV2 metadataQuery;
-    private final MetricsQuery metricsQuery;
-    private final RecordsQuery recordsQuery;
+    private final ModuleManager moduleManager;
+    private final PromQLConfig config;
+    private MetricsMetadataQueryService metricsMetadataQueryService;
+    private MetricsQueryService metricsQueryService;
+    private AggregationQueryService aggregationQueryService;
+    private RecordQueryService recordQueryService;
     private static final ObjectMapper MAPPER = new ObjectMapper();
 
-    public PromQLApiHandler(ModuleManager moduleManager) {
+    public PromQLApiHandler(ModuleManager moduleManager, PromQLConfig config) {
         this.metadataQuery = new MetadataQueryV2(moduleManager);
-        this.metricsQuery = new MetricsQuery(moduleManager);
-        this.recordsQuery = new RecordsQuery(moduleManager);
+        this.moduleManager = moduleManager;
+        this.config = config;
+    }
+
+    private MetricsMetadataQueryService getMetricsMetadataQueryService() {
+        if (metricsMetadataQueryService == null) {
+            this.metricsMetadataQueryService = moduleManager.find(CoreModule.NAME)
+                                                           .provider()
+                                                           .getService(MetricsMetadataQueryService.class);
+        }
+        return metricsMetadataQueryService;
+    }
+
+    private MetricsQueryService getMetricsQueryService() {
+        if (metricsQueryService == null) {
+            this.metricsQueryService = moduleManager.find(CoreModule.NAME)
+                                                    .provider()
+                                                    .getService(MetricsQueryService.class);
+        }
+        return metricsQueryService;
+    }
+
+    private AggregationQueryService getAggregationQueryService() {
+        if (aggregationQueryService == null) {
+            this.aggregationQueryService = moduleManager.find(CoreModule.NAME)
+                                                        .provider()
+                                                        .getService(AggregationQueryService.class);
+        }
+        return aggregationQueryService;
+    }
+
+    private RecordQueryService getRecordQueryService() {
+        if (recordQueryService == null) {
+            this.recordQueryService = moduleManager.find(CoreModule.NAME)
+                                                   .provider()
+                                                   .getService(RecordQueryService.class);
+        }
+        return recordQueryService;
     }
 
     @Get
@@ -110,7 +164,7 @@ public class PromQLApiHandler {
         MetadataQueryRsp response = new MetadataQueryRsp();
         response.setStatus(ResultStatus.SUCCESS);
         String regex = metric.orElse("");
-        List<MetricDefinition> definitionList = metricsQuery.listMetrics(regex);
+        List<MetricDefinition> definitionList = getMetricsMetadataQueryService().listMetrics(regex);
         int inputLimit = limit.orElse(definitionList.size());
         int maxNum = Math.min(inputLimit, definitionList.size());
         for (int i = 0; i < maxNum; i++) {
@@ -123,8 +177,10 @@ public class PromQLApiHandler {
     }
 
     /**
-     * OAP doesn't support query label by start/end,
-     * reserve these param to keep consistent with API protocol.
+     * If match[] is not present, return general labels.
+     * If end time is not present, use current time as default end time.
+     * The start param will be ignored, reserve this param to keep consistent with API protocol.
+     * Always query with day step.
      */
     @Get
     @Post
@@ -134,35 +190,39 @@ public class PromQLApiHandler {
         @Param("start") Optional<String> start,
         @Param("end") Optional<String> end) throws IOException {
         LabelsQueryRsp response = new LabelsQueryRsp();
+        long endTS = System.currentTimeMillis();
+        if (end.isPresent()) {
+            endTS = formatTimestamp2Millis(end.get());
+        }
+        Duration duration = getDayDurationFromTimestamp(endTS);
         if (match.isPresent()) {
-            PromQLLexer lexer = new PromQLLexer(
-                CharStreams.fromString(match.get()));
-            lexer.addErrorListener(new ParseErrorListener());
-            PromQLParser parser = new PromQLParser(new CommonTokenStream(lexer));
-            parser.addErrorListener(new ParseErrorListener());
-            ParseTree tree;
+            MatcherSetResult parseResult;
             try {
-                tree = parser.expression();
+                parseResult = getMatcherSetResult(match.get());
             } catch (ParseCancellationException e) {
                 response.setStatus(ResultStatus.ERROR);
                 response.setErrorType(ErrorType.BAD_DATA);
                 response.setError(e.getMessage());
                 return jsonResponse(response);
             }
-            PromQLMatchVisitor visitor = new PromQLMatchVisitor();
-            MatcherSetResult parseResult = visitor.visit(tree);
             String metricName = parseResult.getMetricName();
             Optional<ValueColumnMetadata.ValueColumn> valueColumn = ValueColumnMetadata.INSTANCE.readValueColumnDefinition(
                 metricName);
             if (valueColumn.isPresent()) {
                 ValueColumnMetadata.ValueColumn metaData = valueColumn.get();
                 Scope scope = Scope.Finder.valueOf(metaData.getScopeId());
-                Column.ValueDataType dataType = metaData.getDataType();
-                response.getData().addAll(buildLabelNames(scope, dataType));
+                response.getData().addAll(buildLabelNames(scope, metaData));
+                if (Column.ValueDataType.LABELED_VALUE == valueColumn.get().getDataType()) {
+                    List<MetricsValues> matchedMetrics = getMatcherMetricsValues(parseResult, duration);
+                    response.getData().addAll(buildLabelNamesFromQuery(matchedMetrics));
+                }
+                if (metaData.isMultiIntValues()) {
+                    response.getData().remove(DataLabel.GENERAL_LABEL_NAME);
+                }
             }
         } else {
             Arrays.stream(LabelName.values()).forEach(label -> {
-                response.getData().add(label);
+                response.getData().add(label.getLabel());
             });
         }
         response.setStatus(ResultStatus.SUCCESS);
@@ -170,8 +230,10 @@ public class PromQLApiHandler {
     }
 
     /**
-     * OAP doesn't support query label value by match/start/end,
-     * reserve these param to keep consistent with API protocol.
+     * If match[] is not present, return general labels values.
+     * If end time is not present, use current time as default end time.
+     * The start param will be ignored, reserve this param to keep consistent with API protocol.
+     * Always query with day step.
      */
     @Get
     @Path("/api/v1/label/{label_name}/values")
@@ -182,23 +244,84 @@ public class PromQLApiHandler {
         @Param("end") Optional<String> end) throws IOException {
         LabelValuesQueryRsp response = new LabelValuesQueryRsp();
         response.setStatus(ResultStatus.SUCCESS);
+        long endTS = System.currentTimeMillis();
+        if (end.isPresent()) {
+            endTS = formatTimestamp2Millis(end.get());
+        }
+        Duration duration = getDayDurationFromTimestamp(endTS);
 
-        switch (LabelName.labelOf(labelName)) {
-            case NAME:
-                metricsQuery.listMetrics("").forEach(definition -> {
-                    response.getData().add(definition.getName());
-                });
-                break;
-            case LAYER:
-                for (Layer layer : Layer.values()) {
-                    response.getData().add(layer.name());
+        //general labels
+        if (LabelName.NAME.getLabel().equals(labelName)) {
+            getMetricsMetadataQueryService().listMetrics("").forEach(definition -> {
+                response.getData().add(definition.getName());
+            });
+            return jsonResponse(response);
+        } else if (LabelName.LAYER.getLabel().equals(labelName)) {
+            for (Layer layer : Layer.values()) {
+                response.getData().add(layer.name());
+            }
+            return jsonResponse(response);
+        } else if (LabelName.SCOPE.getLabel().equals(labelName)) {
+            for (Scope scope : Scope.values()) {
+                response.getData().add(scope.name());
+            }
+            return jsonResponse(response);
+        }
+
+        if (match.isPresent()) {
+            MatcherSetResult parseResult;
+            try {
+                parseResult = getMatcherSetResult(match.get());
+            } catch (ParseCancellationException e) {
+                response.setStatus(ResultStatus.ERROR);
+                response.setErrorType(ErrorType.BAD_DATA);
+                response.setError(e.getMessage());
+                return jsonResponse(response);
+            }
+            String metricName = parseResult.getMetricName();
+            Optional<ValueColumnMetadata.ValueColumn> valueColumn = ValueColumnMetadata.INSTANCE.readValueColumnDefinition(
+                metricName);
+            if (valueColumn.isPresent() && Column.ValueDataType.LABELED_VALUE == valueColumn.get().getDataType()) {
+                List<MetricsValues> matchedMetrics = getMatcherMetricsValues(parseResult, duration);
+                response.getData().addAll(buildLabelValuesFromQuery(matchedMetrics, labelName));
+            } else {
+                // Make compatible with Grafana 11 when use old config variables
+                // e.g. query service list config: `label_values(service_traffic{layer='$layer'}, service)`
+                // Grafana 11 will query this API by default rather than `/api/v1/series`(< 11)
+                if (Objects.equals(metricName, ServiceTraffic.INDEX_NAME)) {
+                    String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
+                    if (StringUtil.isNotBlank(serviceName)) {
+                        Service service = metadataQuery.findService(serviceName).join();
+                        response.getData().add(service.getName());
+                    } else {
+                        List<Service> services = metadataQuery.listServices(
+                            parseResult.getLabelMap().get(LabelName.LAYER.getLabel())).join();
+                        services.forEach(service -> {
+                            response.getData().add(service.getName());
+                        });
+                    }
+                } else if (Objects.equals(metricName, InstanceTraffic.INDEX_NAME)) {
+                    String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
+                    String layer = parseResult.getLabelMap().get(LabelName.LAYER.getLabel());
+                    List<ServiceInstance> instances = metadataQuery.listInstances(
+                        duration, IDManager.ServiceID.buildId(serviceName, Layer.valueOf(layer).isNormal())).join();
+                    instances.forEach(instance -> {
+                        response.getData().add(instance.getName());
+                    });
+                } else if (Objects.equals(metricName, EndpointTraffic.INDEX_NAME)) {
+                    String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
+                    String layer = parseResult.getLabelMap().get(LabelName.LAYER.getLabel());
+                    String keyword = parseResult.getLabelMap().getOrDefault(LabelName.KEYWORD.getLabel(), "");
+                    String limit = parseResult.getLabelMap().getOrDefault(LabelName.LIMIT.getLabel(), "100");
+                    List<Endpoint> endpoints = metadataQuery.findEndpoint(
+                        keyword, IDManager.ServiceID.buildId(serviceName, Layer.valueOf(layer).isNormal()),
+                        Integer.parseInt(limit)
+                    ).join();
+                    endpoints.forEach(endpoint -> {
+                        response.getData().add(endpoint.getName());
+                    });
                 }
-                break;
-            case SCOPE:
-                for (Scope scope : Scope.values()) {
-                    response.getData().add(scope.name());
-                }
-                break;
+            }
         }
 
         return jsonResponse(response);
@@ -215,24 +338,16 @@ public class PromQLApiHandler {
         long endTS = formatTimestamp2Millis(end);
         Duration duration = DurationUtils.timestamp2Duration(startTS, endTS);
         SeriesQueryRsp response = new SeriesQueryRsp();
-        PromQLLexer lexer = new PromQLLexer(
-            CharStreams.fromString(match));
-        lexer.addErrorListener(new ParseErrorListener());
-        PromQLParser parser = new PromQLParser(new CommonTokenStream(lexer));
-        parser.addErrorListener(new ParseErrorListener());
-        ParseTree tree;
+        MatcherSetResult parseResult;
         try {
-            tree = parser.expression();
+            parseResult = getMatcherSetResult(match);
         } catch (ParseCancellationException e) {
             response.setStatus(ResultStatus.ERROR);
             response.setErrorType(ErrorType.BAD_DATA);
             response.setError(e.getMessage());
             return jsonResponse(response);
         }
-        PromQLMatchVisitor visitor = new PromQLMatchVisitor();
-        MatcherSetResult parseResult = visitor.visit(tree);
         String metricName = parseResult.getMetricName();
-
         Optional<ValueColumnMetadata.ValueColumn> valueColumn = ValueColumnMetadata.INSTANCE.readValueColumnDefinition(
             metricName);
         if (valueColumn.isPresent()) {
@@ -241,34 +356,34 @@ public class PromQLApiHandler {
             Column.ValueDataType dataType = metaData.getDataType();
             response.getData().add(buildMetaMetricInfo(metricName, scope, dataType));
         } else if (Objects.equals(metricName, ServiceTraffic.INDEX_NAME)) {
-            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE);
+            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
             if (StringUtil.isNotBlank(serviceName)) {
-                Service service = metadataQuery.findService(serviceName);
+                Service service = metadataQuery.findService(serviceName).join();
                 response.getData().add(buildMetricInfoFromTraffic(metricName, service));
             } else {
                 List<Service> services = metadataQuery.listServices(
-                    parseResult.getLabelMap().get(LabelName.LAYER));
+                    parseResult.getLabelMap().get(LabelName.LAYER.getLabel())).join();
                 services.forEach(service -> {
                     response.getData().add(buildMetricInfoFromTraffic(metricName, service));
                 });
             }
         } else if (Objects.equals(metricName, InstanceTraffic.INDEX_NAME)) {
-            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE);
-            String layer = parseResult.getLabelMap().get(LabelName.LAYER);
+            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
+            String layer = parseResult.getLabelMap().get(LabelName.LAYER.getLabel());
             List<ServiceInstance> instances = metadataQuery.listInstances(
-                duration, IDManager.ServiceID.buildId(serviceName, Layer.valueOf(layer).isNormal()));
+                duration, IDManager.ServiceID.buildId(serviceName, Layer.valueOf(layer).isNormal())).join();
             instances.forEach(instance -> {
                 response.getData().add(buildMetricInfoFromTraffic(metricName, instance));
             });
         } else if (Objects.equals(metricName, EndpointTraffic.INDEX_NAME)) {
-            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE);
-            String layer = parseResult.getLabelMap().get(LabelName.LAYER);
-            String keyword = parseResult.getLabelMap().getOrDefault(LabelName.KEYWORD, "");
-            String limit = parseResult.getLabelMap().getOrDefault(LabelName.LIMIT, "100");
+            String serviceName = parseResult.getLabelMap().get(LabelName.SERVICE.getLabel());
+            String layer = parseResult.getLabelMap().get(LabelName.LAYER.getLabel());
+            String keyword = parseResult.getLabelMap().getOrDefault(LabelName.KEYWORD.getLabel(), "");
+            String limit = parseResult.getLabelMap().getOrDefault(LabelName.LIMIT.getLabel(), "100");
             List<Endpoint> endpoints = metadataQuery.findEndpoint(
                 keyword, IDManager.ServiceID.buildId(serviceName, Layer.valueOf(layer).isNormal()),
                 Integer.parseInt(limit)
-            );
+            ).join();
             endpoints.forEach(endpoint -> {
                 response.getData().add(buildMetricInfoFromTraffic(metricName, endpoint));
             });
@@ -308,7 +423,7 @@ public class PromQLApiHandler {
             return jsonResponse(response);
         }
         PromQLExprQueryVisitor visitor = new PromQLExprQueryVisitor(
-            metricsQuery, recordsQuery, duration, QueryType.INSTANT);
+            getMetricsQueryService(), getRecordQueryService(), getAggregationQueryService(), duration, QueryType.INSTANT);
         ParseResult parseResult = visitor.visit(tree);
 
         if (parseResult == null) {
@@ -370,7 +485,7 @@ public class PromQLApiHandler {
         }
 
         PromQLExprQueryVisitor visitor = new PromQLExprQueryVisitor(
-            metricsQuery, recordsQuery, duration, QueryType.RANGE);
+            getMetricsQueryService(), getRecordQueryService(), getAggregationQueryService(), duration, QueryType.RANGE);
         ParseResult parseResult = visitor.visit(tree);
 
         if (parseResult == null) {
@@ -394,6 +509,21 @@ public class PromQLApiHandler {
         return jsonResponse(response);
     }
 
+    @Get
+    @Post
+    @Path("/api/v1/status/buildinfo")
+    public HttpResponse buildInfo() throws IOException {
+        BuildInfoRsp buildInfoRsp = new BuildInfoRsp();
+        buildInfoRsp.setStatus(ResultStatus.SUCCESS);
+        buildInfoRsp.getData().setVersion(config.getBuildInfoVersion());
+        buildInfoRsp.getData().setRevision(config.getBuildInfoRevision());
+        buildInfoRsp.getData().setBranch(config.getBuildInfoBranch());
+        buildInfoRsp.getData().setBuildUser(config.getBuildInfoBuildUser());
+        buildInfoRsp.getData().setBuildDate(config.getBuildInfoBuildDate());
+        buildInfoRsp.getData().setGoVersion(config.getBuildInfoGoVersion());
+        return jsonResponse(buildInfoRsp);
+    }
+
     private HttpResponse jsonResponse(QueryResponse response) throws JsonProcessingException {
         return HttpResponse.of(ResponseHeaders.builder(HttpStatus.OK)
                                               .contentType(MediaType.JSON)
@@ -453,62 +583,90 @@ public class PromQLApiHandler {
     }
 
     private static long formatTimestamp2Millis(String timestamp) {
-        return Double.valueOf(timestamp).longValue() * 1000;
+        long time;
+        try {
+            // if Unix timestamp in seconds, such as 1627756800
+            time = Double.valueOf(timestamp).longValue() * 1000;
+        } catch (NumberFormatException e) {
+            // if RFC3399 format, such as 2024-09-19T20:11:00.781Z
+            time = ISODateTimeFormat.dateTime().parseMillis(timestamp);
+        }
+        return time;
     }
 
-    private List<LabelName> buildLabelNames(Scope scope,
-                                            Column.ValueDataType dataType) {
-        List<LabelName> labelNames = new ArrayList<>();
-        labelNames.add(LabelName.LAYER);
-        labelNames.add(LabelName.SERVICE);
-        labelNames.add(LabelName.TOP_N);
-        labelNames.add(LabelName.ORDER);
-        if (Column.ValueDataType.LABELED_VALUE == dataType) {
-            labelNames.add(LabelName.LABELS);
-            labelNames.add(LabelName.RELABELS);
+    private List<String> buildLabelNames(Scope scope, ValueColumnMetadata.ValueColumn metaData) {
+        List<String> labelNames = new ArrayList<>();
+        labelNames.add(LabelName.LAYER.getLabel());
+        labelNames.add(LabelName.SERVICE.getLabel());
+        labelNames.add(LabelName.TOP_N.getLabel());
+        labelNames.add(LabelName.ORDER.getLabel());
+        if (metaData.isMultiIntValues()) {
+            labelNames.add(LabelName.LABELS.getLabel());
+            labelNames.add(LabelName.RELABELS.getLabel());
         }
         switch (scope) {
             case ServiceInstance:
-                labelNames.add(LabelName.SERVICE_INSTANCE);
-                labelNames.add(LabelName.PARENT_SERVICE);
+                labelNames.add(LabelName.SERVICE_INSTANCE.getLabel());
+                labelNames.add(LabelName.PARENT_SERVICE.getLabel());
                 break;
             case Endpoint:
-                labelNames.add(LabelName.ENDPOINT);
-                labelNames.add(LabelName.PARENT_SERVICE);
+                labelNames.add(LabelName.ENDPOINT.getLabel());
+                labelNames.add(LabelName.PARENT_SERVICE.getLabel());
                 break;
         }
         return labelNames;
     }
 
+    private List<String> buildLabelNamesFromQuery(List<MetricsValues> metricsValues) {
+        Set<String> labelNames = new LinkedHashSet<>();
+        metricsValues.forEach(metricsValue -> {
+            DataLabel dataLabel = new DataLabel();
+            dataLabel.put(metricsValue.getLabel());
+            labelNames.addAll(dataLabel.keySet());
+        });
+        return Arrays.asList(labelNames.toArray(new String[0]));
+    }
+
+    private List<String> buildLabelValuesFromQuery(List<MetricsValues> metricsValues, String labelName) {
+        Set<String> labelValues = new LinkedHashSet<>();
+        metricsValues.forEach(metricsValue -> {
+            DataLabel dataLabel = new DataLabel();
+            dataLabel.put(metricsValue.getLabel());
+            labelValues.add(dataLabel.get(labelName));
+        });
+        return Arrays.asList(labelValues.toArray(new String[0]));
+    }
+
+
     //Only return label names, don't support list the product of all the labels and label values.
     private MetricInfo buildMetaMetricInfo(String metricName,
                                            Scope scope,
                                            Column.ValueDataType dataType) {
         MetricInfo metricInfo = new MetricInfo(metricName);
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.LAYER, ""));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.TOP_N, ""));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.ORDER, ""));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.LAYER.getLabel(), ""));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.TOP_N.getLabel(), ""));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.ORDER.getLabel(), ""));
 
         if (Column.ValueDataType.LABELED_VALUE == dataType) {
-            metricInfo.getLabels().add(new LabelValuePair(LabelName.LABELS, ""));
-            metricInfo.getLabels().add(new LabelValuePair(LabelName.RELABELS, ""));
+            metricInfo.getLabels().add(new LabelValuePair(LabelName.LABELS.getLabel(), ""));
+            metricInfo.getLabels().add(new LabelValuePair(LabelName.RELABELS.getLabel(), ""));
         }
         switch (scope) {
             case Service:
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.Service.name()));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE, ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.Service.name()));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE.getLabel(), ""));
                 break;
             case ServiceInstance:
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.ServiceInstance.name()));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE, ""));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE_INSTANCE, ""));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.PARENT_SERVICE, ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.ServiceInstance.name()));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE.getLabel(), ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE_INSTANCE.getLabel(), ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.PARENT_SERVICE.getLabel(), ""));
                 break;
             case Endpoint:
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.Endpoint.name()));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE, ""));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.ENDPOINT, ""));
-                metricInfo.getLabels().add(new LabelValuePair(LabelName.PARENT_SERVICE, ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.Endpoint.name()));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE.getLabel(), ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.ENDPOINT.getLabel(), ""));
+                metricInfo.getLabels().add(new LabelValuePair(LabelName.PARENT_SERVICE.getLabel(), ""));
                 break;
         }
         return metricInfo;
@@ -516,27 +674,59 @@ public class PromQLApiHandler {
 
     private MetricInfo buildMetricInfoFromTraffic(String metricName, Service service) {
         MetricInfo metricInfo = new MetricInfo(metricName);
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE, service.getName()));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.Service.name()));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.LAYER, service.getLayers().iterator().next()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.SERVICE.getLabel(), service.getName()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.Service.name()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.LAYER.getLabel(), service.getLayers().iterator().next()));
         return metricInfo;
     }
 
     private MetricInfo buildMetricInfoFromTraffic(String metricName, ServiceInstance instance) {
         MetricInfo metricInfo = new MetricInfo(metricName);
         metricInfo.getLabels()
-                  .add(new LabelValuePair(LabelName.SERVICE_INSTANCE, instance.getName()));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.ServiceInstance.name()));
+                  .add(new LabelValuePair(LabelName.SERVICE_INSTANCE.getLabel(), instance.getName()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.ServiceInstance.name()));
         return metricInfo;
     }
 
     private MetricInfo buildMetricInfoFromTraffic(String metricName, Endpoint endpoint) {
         MetricInfo metricInfo = new MetricInfo(metricName);
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.ENDPOINT, endpoint.getName()));
-        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE, Scope.Endpoint.name()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.ENDPOINT.getLabel(), endpoint.getName()));
+        metricInfo.getLabels().add(new LabelValuePair(LabelName.SCOPE.getLabel(), Scope.Endpoint.name()));
         return metricInfo;
     }
 
+    private Duration getDayDurationFromTimestamp(long timeTS) {
+        Duration duration = new Duration();
+        DateTime dt = new DateTime(timeTS);
+        duration.setStep(Step.DAY);
+        duration.setStart(dt.toString(DurationUtils.YYYY_MM_DD));
+        duration.setEnd(dt.toString(DurationUtils.YYYY_MM_DD));
+        return duration;
+    }
+
+    private MatcherSetResult getMatcherSetResult(String matchString) {
+        PromQLLexer lexer = new PromQLLexer(
+            CharStreams.fromString(matchString));
+        lexer.addErrorListener(new ParseErrorListener());
+        PromQLParser parser = new PromQLParser(new CommonTokenStream(lexer));
+        parser.addErrorListener(new ParseErrorListener());
+        ParseTree tree = parser.expression();
+        PromQLMatchVisitor visitor = new PromQLMatchVisitor();
+        return visitor.visit(tree);
+    }
+
+    private List<MetricsValues> getMatcherMetricsValues(MatcherSetResult parseResult,  Duration duration) throws IOException {
+        String metricName = parseResult.getMetricName();
+        List<KeyValue> matchLabels = parseResult.getLabelMap().entrySet().stream().map(entry -> {
+            KeyValue keyValue = new KeyValue();
+            keyValue.setKey(entry.getKey());
+            keyValue.setValue(entry.getValue());
+            return keyValue;
+        }).collect(Collectors.toList());
+
+        return getMetricsQueryService().readLabeledMetricsValuesWithoutEntity(metricName, matchLabels, duration);
+    }
+
     public enum QueryType {
         INSTANT,
         RANGE,
