@@ -41,6 +41,10 @@ public class BanyanDBStorageConfig extends ModuleConfig {
      * Period of flush interval. In the timeunit of seconds.
      */
     private int flushInterval = 15;
+    /**
+     * Timeout of flush. In the timeunit of seconds.
+     */
+    private int flushTimeout = 10;
     /**
      * Concurrent consumer threads for batch writing.
      */
@@ -62,13 +66,6 @@ public class BanyanDBStorageConfig extends ModuleConfig {
      * Shards Factor for a super dataset
      */
     private int superDatasetShardsFactor;
-    /**
-     * Default global block interval for non-super-dataset models.
-     * Unit is hour.
-     *
-     * @since 9.4.0
-     */
-    private int blockIntervalHours;
     /**
      * Default global segment interval for non-super-dataset models.
      * Unit is day.
@@ -76,13 +73,6 @@ public class BanyanDBStorageConfig extends ModuleConfig {
      * @since 9.4.0
      */
     private int segmentIntervalDays;
-    /**
-     * Default global block interval for super-dataset models.
-     * Unit is hour.
-     *
-     * @since 9.4.0
-     */
-    private int superDatasetBlockIntervalHours;
     /**
      * Default global segment interval for super-dataset models.
      * Unit is day.
@@ -103,6 +93,11 @@ public class BanyanDBStorageConfig extends ModuleConfig {
      */
     private String specificGroupSettings;
 
+    /**
+     * If the BanyanDB server is configured with TLS, config the TLS cert file path and open tls connection.
+     */
+    private String sslTrustCAPath = "";
+
     public String[] getTargetArray() {
         return Iterables.toArray(Splitter.on(",").omitEmptyStrings().trimResults().split(this.targets), String.class);
     }
