@@ -30,6 +30,12 @@ const titles = {
   general_service_virtual_mq: "MQ virtual",
   general_service_virtual_mq_desc:
     "Observe the virtual message queue servers which are conjectured by language agents through various plugins.",
+  // Workflow Scheduler
+  workflow_scheduler: "Flujo de trabajo",
+  workflow_scheduler_desc: "Proporcionar monitoreo para sistemas de programación de flujos de trabajo.",
+  workflow_scheduler_airflow: "Airflow",
+  workflow_scheduler_airflow_desc:
+    "Observando tareas a través de los datos de telemetría recopilados desde Apache Airflow.",
   // Service Mesh
   service_mesh: "Malla de Servicios",
   service_mesh_desc:
@@ -108,6 +114,8 @@ const titles = {
   mq_kafka_desc: "Provide Kafka monitoring through OpenTelemetry's Prometheus Receiver.",
   mq_pulsar: "Pulsar",
   mq_pulsar_desc: "Provide Pulsar monitoring through OpenTelemetry's Prometheus Receiver.",
+  mq_rocketmq: "RocketMQ",
+  mq_rocketmq_desc: "Provide RocketMQ monitoring through OpenTelemetry's Prometheus Receiver.",
   // self observability
   self_observability: "Self Observability",
   self_observability_desc:
@@ -118,6 +126,14 @@ const titles = {
   self_observability_satellite: "Satellite",
   self_observability_satellite_desc:
     "Satellite: an open-source agent designed for the cloud-native infrastructures, which provides a low-cost, high-efficient, and more secure way to collect telemetry data. It is the recommended load balancer for telemetry collecting.",
+  self_observability_java_agent: "SkyWalking Java Agent",
+  self_observability_java_agent_desc:
+    "The self observability of SkyWalking Java Agent, which provides the abilities to measure the tracing performance and error statistics of plugins.",
+  cilium: "Cilium",
+  cilium_desc:
+    "Cilium es un complemento CNI para Kubernetes que proporciona redes, seguridad y equilibrio de carga basados en eBPF.",
+  cilium_service: "Cilium Service",
+  cilium_service_desc: "Observe el estado del servicio y los recursos de Cilium Hubble.",
 };
 
 export default titles;
