@@ -26,6 +26,11 @@ const titles = {
   general_service_virtual_cache_desc: "观察语言代理通过各种插件推测的虚拟缓存服务器。",
   general_service_virtual_mq: "虚拟消息队列",
   general_service_virtual_mq_desc: "观察语言代理通过各种插件推测的虚拟消息队列服务器。",
+  // Workflow Scheduler
+  workflow_scheduler: "工作流调度",
+  workflow_scheduler_desc: "提供工作流调度系统监控。",
+  workflow_scheduler_airflow: "Airflow",
+  workflow_scheduler_airflow_desc: "通过从Apache Airflow收集的遥测数据观察任务。",
   // Service Mesh
   service_mesh: "服务网格",
   service_mesh_desc: "服务网格（Istio）通过分布式或微服务架构解决了开发人员和运营商面临的挑战。",
@@ -96,6 +101,8 @@ const titles = {
   mq_Kafka_desc: "通过OpenTelemetry的Prometheus接收器提供Kafka监控。",
   mq_pulsar: "Pulsar",
   mq_Pulsar_desc: "通过OpenTelemetry的Prometheus接收器提供Pulsar监控。",
+  mq_rocketmq: "RocketMQ",
+  mq_rocketmq_desc: "通过OpenTelemetry的Prometheus接收器提供RocketMQ监控。",
   // self observability
   self_observability: "自监控",
   self_observability_desc: "自观察性为运行SkyWalking生态系统中的组件和服务器提供了可观察性。",
@@ -104,6 +111,12 @@ const titles = {
   self_observability_satellite: "Satellite",
   self_observability_satellite_desc:
     "Satellite：为云原生基础设施设计的开源代理，提供了一种低成本、高效、更安全的遥测数据收集方式。它是遥测采集的推荐负载均衡器。",
+  self_observability_java_agent: "SkyWalking Java Agent",
+  self_observability_java_agent_desc: "SkyWalking Java Agent 自监控提供了对 agent 插件的性能追踪和错误统计。",
+  cilium: "Cilium",
+  cilium_desc: "Cilium是Kubernetes上的CNI插件，提供基于eBPF的网络、安全和负载均衡。",
+  cilium_service: "Cilium服务",
+  cilium_service_desc: "通过Cilium Hubble收集的遥测数据观察服务。",
 };
 
 export default titles;
