@@ -99,8 +99,7 @@ const msg = {
   import: "导入仪表板模板",
   yes: "是",
   no: "否",
-  tableHeaderCol1: "表格的第一列的名称",
-  tableHeaderCol2: "表格的第二列的名称",
+  tableHeaderCol2: "表格的最后一列的名称",
   showXAxis: "显示X轴",
   showYAxis: "显示Y轴",
   nameError: "仪表板名称不能重复",
@@ -282,7 +281,8 @@ const msg = {
   errorInfo: "错误信息",
   stack: "堆栈",
   serviceVersion: "服务版本",
-  errorPage: "错误页面",
+  pagePath: "错误页面",
+  errorUrl: "错误路径",
   category: "类别",
   grade: "等级",
   relatedTraceLogs: "相关的日志",
@@ -376,11 +376,13 @@ const msg = {
   menusManagement: "菜单",
   saveReload: "保存并重新加载页面",
   document: "文档",
-  metricMode: "指标模式",
   addExpressions: "添加表达式",
   expressions: "表达式",
   unhealthyExpression: "非健康表达式",
   traceDesc:
     "Trace Segment代表在单一操作系统进程（例如JVM）中执行的追踪部分。它包含了一组跨度（spans），这些跨度通常与单一请求或执行上下文关联。",
+  tabExpressions: "Tab表达式",
+  hierarchyNodeMetrics: "层次图节点的指标",
+  hierarchyNodeDashboard: "作为层次图节点的dashboard",
 };
 export default msg;
