@@ -16,14 +16,13 @@
  */
 import { defineStore } from "pinia";
 import { store } from "@/store";
-import type { Service } from "@/types/selector";
-import type { Node, Call } from "@/types/topology";
+import type { Node, Call, HierarchyNode, ServiceHierarchy, InstanceHierarchy } from "@/types/topology";
 import graphql from "@/graphql";
 import { useSelectorStore } from "@/store/modules/selectors";
+import { useDashboardStore } from "@/store/modules/dashboard";
 import { useAppStoreWithOut } from "@/store/modules/app";
 import type { AxiosResponse } from "axios";
 import query from "@/graphql/fetch";
-import { useQueryTopologyMetrics } from "@/hooks/useMetricsProcessor";
 import { useQueryTopologyExpressionsProcessor } from "@/hooks/useExpressionsProcessor";
 import { ElMessage } from "element-plus";
 
@@ -35,9 +34,15 @@ interface TopologyState {
   call: Nullable<Call>;
   calls: Call[];
   nodes: Node[];
+  hierarchyServiceCalls: Call[];
+  hierarchyServiceNodes: HierarchyNode[];
+  hierarchyInstanceCalls: Call[];
+  hierarchyInstanceNodes: HierarchyNode[];
   nodeMetricValue: MetricVal;
   linkServerMetrics: MetricVal;
   linkClientMetrics: MetricVal;
+  hierarchyNodeMetrics: { [key: string]: MetricVal };
+  hierarchyInstanceNodeMetrics: { [key: string]: MetricVal };
 }
 
 export const topologyStore = defineStore({
@@ -45,11 +50,17 @@ export const topologyStore = defineStore({
   state: (): TopologyState => ({
     calls: [],
     nodes: [],
+    hierarchyServiceCalls: [],
+    hierarchyServiceNodes: [],
+    hierarchyInstanceCalls: [],
+    hierarchyInstanceNodes: [],
     node: null,
     call: null,
     nodeMetricValue: {},
     linkServerMetrics: {},
     linkClientMetrics: {},
+    hierarchyNodeMetrics: {},
+    hierarchyInstanceNodeMetrics: {},
   }),
   actions: {
     setNode(node: Node) {
@@ -75,12 +86,9 @@ export const topologyStore = defineStore({
     },
     setTopology(data: { nodes: Node[]; calls: Call[] }) {
       const obj = {} as Recordable;
-      const services = useSelectorStore().services;
       const nodes = (data.nodes || []).reduce((prev: Node[], next: Node) => {
         if (!obj[next.id]) {
           obj[next.id] = true;
-          const s = services.filter((d: Service) => d.id === next.id)[0] || {};
-          next.layer = s.layers ? s.layers[0] : null;
           prev.push(next);
         }
         return prev;
@@ -106,8 +114,107 @@ export const topologyStore = defineStore({
       this.calls = calls;
       this.nodes = nodes;
     },
-    setNodeMetricValue(m: MetricVal) {
-      this.nodeMetricValue = m;
+    setHierarchyInstanceTopology(data: InstanceHierarchy, levels: { layer: string; level: number }[]) {
+      const relations = data.relations || [];
+      const nodesMap = new Map();
+      const callList = [];
+
+      for (const relation of relations) {
+        const upperId = relation.upperInstance.id;
+        const lowerId = relation.lowerInstance.id;
+        const lowerKey = `${lowerId}-${relation.lowerInstance.layer}`;
+        const upperKey = `${upperId}-${relation.upperInstance.layer}`;
+        const lowerLevel = levels.find(
+          (l: { layer: string; level: number }) => l.layer === relation.lowerInstance.layer,
+        ) || { level: undefined };
+        const upperLevel = levels.find(
+          (l: { layer: string; level: number }) => l.layer === relation.upperInstance.layer,
+        ) || { level: undefined };
+        const lowerObj = {
+          ...relation.lowerInstance,
+          key: lowerId,
+          id: lowerKey,
+          l: lowerLevel.level,
+        };
+        const upperObj = {
+          ...relation.upperInstance,
+          key: upperId,
+          id: upperKey,
+          l: upperLevel.level,
+        };
+        if (!nodesMap.get(upperKey)) {
+          nodesMap.set(upperKey, upperObj);
+        }
+        if (!nodesMap.get(lowerKey)) {
+          nodesMap.set(lowerKey, lowerObj);
+        }
+        callList.push({
+          target: lowerKey,
+          source: upperKey,
+          id: `${lowerKey}->${upperKey}`,
+          sourceObj: upperObj,
+          targetObj: lowerObj,
+        });
+      }
+      this.hierarchyInstanceCalls = callList;
+      this.hierarchyInstanceNodes = [];
+      for (const d of nodesMap.values()) {
+        this.hierarchyInstanceNodes.push(d);
+      }
+    },
+    setHierarchyServiceTopology(data: ServiceHierarchy, levels: { layer: string; level: number }[]) {
+      const relations = data.relations || [];
+      const nodesMap = new Map();
+      const callList = [];
+
+      for (const relation of relations) {
+        const upperId = relation.upperService.id;
+        const lowerId = relation.lowerService.id;
+        const lowerKey = `${lowerId}-${relation.lowerService.layer}`;
+        const upperKey = `${upperId}-${relation.upperService.layer}`;
+        const lowerLevel = levels.find(
+          (l: { layer: string; level: number }) => l.layer === relation.lowerService.layer,
+        ) || { level: undefined };
+        const upperLevel = levels.find(
+          (l: { layer: string; level: number }) => l.layer === relation.upperService.layer,
+        ) || { level: undefined };
+        const lowerObj = {
+          ...relation.lowerService,
+          key: lowerId,
+          id: lowerKey,
+          l: lowerLevel.level,
+        };
+        const upperObj = {
+          ...relation.upperService,
+          key: upperId,
+          id: upperKey,
+          l: upperLevel.level,
+        };
+        if (!nodesMap.get(upperKey)) {
+          nodesMap.set(upperKey, upperObj);
+        }
+        if (!nodesMap.get(lowerKey)) {
+          nodesMap.set(lowerKey, lowerObj);
+        }
+        callList.push({
+          target: lowerKey,
+          source: upperKey,
+          id: `${lowerKey}->${upperKey}`,
+          sourceObj: upperObj,
+          targetObj: lowerObj,
+        });
+      }
+      this.hierarchyServiceCalls = callList;
+      this.hierarchyServiceNodes = [];
+      for (const d of nodesMap.values()) {
+        this.hierarchyServiceNodes.push(d);
+      }
+    },
+    setHierarchyNodeMetricValue(m: MetricVal, layer: string) {
+      this.hierarchyNodeMetrics[layer] = m;
+    },
+    setHierarchyInstanceNodeMetricValue(m: MetricVal, layer: string) {
+      this.hierarchyInstanceNodeMetrics[layer] = m;
     },
     setLinkServerMetrics(m: MetricVal) {
       this.linkServerMetrics = m;
@@ -115,12 +222,16 @@ export const topologyStore = defineStore({
     setLinkClientMetrics(m: MetricVal) {
       this.linkClientMetrics = m;
     },
+    setNodeMetricValue(m: MetricVal) {
+      this.nodeMetricValue = m;
+    },
     setLegendValues(expressions: string, data: { [key: string]: any }) {
-      for (let idx = 0; idx < this.nodes.length; idx++) {
+      const nodeArr = this.nodes.filter((d: Node) => d.isReal);
+      for (let idx = 0; idx < nodeArr.length; idx++) {
         for (let index = 0; index < expressions.length; index++) {
           const k = "expression" + idx + index;
           if (expressions[index]) {
-            this.nodes[idx][expressions[index]] = Number(data[k].results[0].values[0].value);
+            nodeArr[idx][expressions[index]] = Number(data[k].results[0].values[0].value);
           }
         }
       }
@@ -332,15 +443,6 @@ export const topologyStore = defineStore({
 
       return { calls, nodes };
     },
-    async getNodeMetricValue(param: { queryStr: string; conditions: { [key: string]: unknown } }) {
-      const res: AxiosResponse = await query(param);
-
-      if (res.data.errors) {
-        return res.data;
-      }
-      this.setNodeMetricValue(res.data.data);
-      return res.data;
-    },
     async getNodeExpressionValue(param: { queryStr: string; conditions: { [key: string]: unknown } }) {
       const res: AxiosResponse = await query(param);
 
@@ -350,38 +452,6 @@ export const topologyStore = defineStore({
 
       return res.data;
     },
-    async getLinkClientMetrics(linkClientMetrics: string[]) {
-      if (!linkClientMetrics.length) {
-        this.setLinkClientMetrics({});
-        return;
-      }
-      const idsC = this.calls.filter((i: Call) => i.detectPoints.includes("CLIENT")).map((b: Call) => b.id);
-      if (!idsC.length) {
-        return;
-      }
-      const param = await useQueryTopologyMetrics(linkClientMetrics, idsC);
-      const res = await this.getCallClientMetrics(param);
-
-      if (res.errors) {
-        ElMessage.error(res.errors);
-      }
-    },
-    async getLinkServerMetrics(linkServerMetrics: string[]) {
-      if (!linkServerMetrics.length) {
-        this.setLinkServerMetrics({});
-        return;
-      }
-      const idsS = this.calls.filter((i: Call) => i.detectPoints.includes("SERVER")).map((b: Call) => b.id);
-      if (!idsS.length) {
-        return;
-      }
-      const param = await useQueryTopologyMetrics(linkServerMetrics, idsS);
-      const res = await this.getCallServerMetrics(param);
-
-      if (res.errors) {
-        ElMessage.error(res.errors);
-      }
-    },
     async getLinkExpressions(expressions: string[], type: string) {
       if (!expressions.length) {
         this.setLinkServerMetrics({});
@@ -405,22 +475,6 @@ export const topologyStore = defineStore({
         this.setLinkClientMetrics(metrics);
       }
     },
-    async queryNodeMetrics(nodeMetrics: string[]) {
-      if (!nodeMetrics.length) {
-        this.setNodeMetricValue({});
-        return;
-      }
-      const ids = this.nodes.map((d: Node) => d.id);
-      if (!ids.length) {
-        return;
-      }
-      const param = await useQueryTopologyMetrics(nodeMetrics, ids);
-      const res = await this.getNodeMetricValue(param);
-
-      if (res.errors) {
-        ElMessage.error(res.errors);
-      }
-    },
     async queryNodeExpressions(expressions: string[]) {
       if (!expressions.length) {
         this.setNodeMetricValue({});
@@ -432,7 +486,7 @@ export const topologyStore = defineStore({
       }
       const { getExpressionQuery, handleExpressionValues } = useQueryTopologyExpressionsProcessor(
         expressions,
-        this.nodes,
+        this.nodes.filter((d: Node) => d.isReal),
       );
       const param = getExpressionQuery();
       const res = await this.getNodeExpressionValue(param);
@@ -443,44 +497,97 @@ export const topologyStore = defineStore({
       const metrics = handleExpressionValues(res.data);
       this.setNodeMetricValue(metrics);
     },
-    async getLegendMetrics(param: { queryStr: string; conditions: { [key: string]: unknown } }) {
-      const res: AxiosResponse = await query(param);
-
+    async getHierarchyServiceTopology() {
+      const dashboardStore = useDashboardStore();
+      const { currentService } = useSelectorStore();
+      const id = this.node ? this.node.id : (currentService || {}).id;
+      let layer = dashboardStore.layerId;
+      if (this.node) {
+        layer = this.node.layers.includes(dashboardStore.layerId)
+          ? dashboardStore.layerId
+          : this.node.layers.filter((d: string) => d !== dashboardStore.layerId)[0];
+      }
+      if (!(id && layer)) {
+        return new Promise((resolve) => resolve({}));
+      }
+      const res: AxiosResponse = await graphql
+        .query("getHierarchyServiceTopology")
+        .params({ serviceId: id, layer: layer });
       if (res.data.errors) {
         return res.data;
       }
-      const data = res.data.data;
-      const metrics = Object.keys(data);
-      this.nodes = this.nodes.map((d: Node & Recordable) => {
-        for (const m of metrics) {
-          for (const val of data[m].values) {
-            if (d.id === val.id) {
-              d[m] = val.value;
-            }
-          }
-        }
-        return d;
-      });
+      const resp = await this.getListLayerLevels();
+      if (resp.errors) {
+        return resp;
+      }
+      const levels = resp.data.levels || [];
+      this.setHierarchyServiceTopology(res.data.data.hierarchyServiceTopology || {}, levels);
       return res.data;
     },
-    async getCallServerMetrics(param: { queryStr: string; conditions: { [key: string]: unknown } }) {
-      const res: AxiosResponse = await query(param);
+    async getListLayerLevels() {
+      const res: AxiosResponse = await graphql.query("queryListLayerLevels").params({});
 
-      if (res.data.errors) {
-        return res.data;
-      }
-      this.setLinkServerMetrics(res.data.data);
       return res.data;
     },
-    async getCallClientMetrics(param: { queryStr: string; conditions: { [key: string]: unknown } }) {
-      const res: AxiosResponse = await query(param);
+    async getHierarchyInstanceTopology() {
+      const { currentPod } = useSelectorStore();
+      const dashboardStore = useDashboardStore();
 
+      if (!(currentPod && dashboardStore.layerId)) {
+        return new Promise((resolve) => resolve({}));
+      }
+      const res: AxiosResponse = await graphql
+        .query("getHierarchyInstanceTopology")
+        .params({ instanceId: currentPod.id, layer: dashboardStore.layerId });
       if (res.data.errors) {
         return res.data;
       }
-      this.setLinkClientMetrics(res.data.data);
+      const resp = await this.getListLayerLevels();
+      if (resp.errors) {
+        return resp;
+      }
+      const levels = resp.data.levels || [];
+      this.setHierarchyInstanceTopology(res.data.data.hierarchyInstanceTopology || {}, levels);
       return res.data;
     },
+    async queryHierarchyExpressions(expressions: string[], nodes: Node[]) {
+      const { getExpressionQuery, handleExpressionValues } = useQueryTopologyExpressionsProcessor(expressions, nodes);
+      const param = getExpressionQuery();
+      const res = await this.getNodeExpressionValue(param);
+      if (res.errors) {
+        ElMessage.error(res.errors);
+        return;
+      }
+      const metrics = handleExpressionValues(res.data);
+      return metrics;
+    },
+    async queryHierarchyNodeExpressions(expressions: string[], layer: string) {
+      const nodes = this.hierarchyServiceNodes.filter((n: HierarchyNode) => n.layer === layer);
+      if (!nodes.length) {
+        this.setHierarchyNodeMetricValue({}, layer);
+        return;
+      }
+      if (!expressions.length) {
+        this.setHierarchyNodeMetricValue({}, layer);
+        return;
+      }
+      const metrics = await this.queryHierarchyExpressions(expressions, nodes);
+      this.setHierarchyNodeMetricValue(metrics, layer);
+    },
+    async queryHierarchyInstanceNodeExpressions(expressions: string[], layer: string) {
+      const nodes = this.hierarchyInstanceNodes.filter((n: HierarchyNode) => n.layer === layer);
+
+      if (!expressions.length) {
+        this.setHierarchyInstanceNodeMetricValue({}, layer);
+        return;
+      }
+      if (!nodes.length) {
+        this.setHierarchyInstanceNodeMetricValue({}, layer);
+        return;
+      }
+      const metrics = await this.queryHierarchyExpressions(expressions, nodes);
+      this.setHierarchyInstanceNodeMetricValue(metrics, layer);
+    },
   },
 });
 
