@@ -25,7 +25,10 @@ import Ebpf from "./Ebpf.vue";
 import DemandLog from "./DemandLog.vue";
 import Event from "./Event.vue";
 import NetworkProfiling from "./NetworkProfiling.vue";
+import ContinuousProfiling from "./ContinuousProfiling.vue";
 import TimeRange from "./TimeRange.vue";
+import ThirdPartyApp from "./ThirdPartyApp.vue";
+import TaskTimeline from "./TaskTimeline.vue";
 
 export default {
   Tab,
@@ -39,5 +42,8 @@ export default {
   DemandLog,
   Event,
   NetworkProfiling,
+  ContinuousProfiling,
   TimeRange,
+  ThirdPartyApp,
+  TaskTimeline,
 };
