@@ -47,6 +47,7 @@ export default class ListGraph {
     this.el = el;
     this.width = el.getBoundingClientRect().width - 10;
     this.height = el.getBoundingClientRect().height - 10;
+    d3.select(".trace-list-dowanload").remove();
     this.svg = d3
       .select(this.el)
       .append("svg")
@@ -217,14 +218,14 @@ export default class ListGraph {
       .append("text")
       .attr("x", 13)
       .attr("y", 5)
-      .attr("fill", appStore.theme === Themes.Dark ? "#666" : "#E54C17")
+      .attr("fill", `#e54c17`)
       .html((d: Recordable) => (d.data.isError ? "◉" : ""));
     nodeEnter
       .append("text")
       .attr("class", "node-text")
       .attr("x", 35)
       .attr("y", -6)
-      .attr("fill", appStore.theme === Themes.Dark ? "#eee" : "#333")
+      .attr("fill", (d: Recordable) => (d.data.isError ? `#e54c17` : appStore.theme === Themes.Dark ? "#eee" : "#333"))
       .html((d: Recordable) => {
         if (d.data.label === "TRACE_ROOT") {
           return "";
@@ -384,15 +385,4 @@ export default class ListGraph {
   visDate(date: number, pattern = "YYYY-MM-DD HH:mm:ss:SSS") {
     return dayjs(date).format(pattern);
   }
-  resize() {
-    if (!this.el) {
-      return;
-    }
-    this.width = this.el.getBoundingClientRect().width - 20;
-    this.height = this.el.getBoundingClientRect().height - 10;
-    this.svg.attr("width", this.width).attr("height", this.height);
-    this.svg.select("g").attr("transform", () => `translate(160, 0)`);
-    const transform = d3.zoomTransform(this.svg).translate(0, 0);
-    d3.zoom().transform(this.svg, transform);
-  }
 }
